==> ark-18.07.80.tar.xz: ark-18.07.80/plugins/cli7zplugin/kerfuffle_cli7z.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for the zip and 7z archive formats",
        "Description[ca@valencia]": "Implementació completa dels formats d'arxiu «zip» i «7z»",
        "Description[ca]": "Implementació completa dels formats d'arxiu «zip» i «7z»",
        "Description[cs]": "Plná podpora archivačních formátů zip a 7z",
        "Description[da]": "Fuld understøttelse af zip- og 7z-arkivformater",
        "Description[de]": "Vollständige Unterstützung für Zip- und 7z-Archivformate",
        "Description[el]": "Πλήρης υποστήριξη για την αρχειοθήκη μορφής zip και 7z",
        "Description[es]": "Uso total de los formatos de archivos comprimidos zip y 7z",
        "Description[eu]": "zip eta 7z artxibo fitxategientzako euskarri osoa",
        "Description[fi]": "Täysi Zip- ja 7z-tiedostomuotojen tuki",
        "Description[fr]": "Prise en charge complète des formats d'archive zip et 7z",
        "Description[gl]": "Compatibilidade total cos formatos de arquivo zip and 7z.",
        "Description[it]": "Supporto completo per i formati di archivi zip e 7z",
        "Description[ko]": "zip 및 7z 압축 형식 지원",
        "Description[nl]": "Volledige ondersteuning voor de zip- en 7z-archiefformaten",
        "Description[nn]": "Full støtte for arkivformata ZIP og 7z",
        "Description[pl]": "Pełna obsługa dla archiwów zip oraz 7z",
        "Description[pt]": "Suporte total para os formatos de pacotes ZIP e 7z",
        "Description[ru]": "Полная поддержка архивов ZIP и 7z",
        "Description[sk]": "Plná podpora pre archívne formáty zip a 7z",
        "Description[sl]": "Polna podpora za arhive vrste zip in 7z",
        "Description[sr@ijekavian]": "Пуна подршка за архивске формате ЗИП и 7зип",
        "Description[sr@ijekavianlatin]": "Puna podrška za arhivske formate ZIP i 7zip",
        "Description[sr@latin]": "Puna podrška za arhivske formate ZIP i 7zip",
        "Description[sr]": "Пуна подршка за архивске формате ЗИП и 7зип",
        "Description[sv]": "Fullt stöd för zip- och 7z-arkivformaten",
        "Description[tr]": "Zip ve 7z arşiv biçimleri için tam destek",
        "Description[uk]": "Повноцінна підтримка архівів у форматах zip і 7z",
        "Description[x-test]": "xxFull support for the zip and 7z archive formatsxx",
        "Description[zh_CN]": "完全支持 zip 和 7z 归档格式",
        "Description[zh_TW]": "對 zip 與 7z 壓縮檔格式的完整支援",
        "Id": "kerfuffle_cli7z",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "P7zip plugin",
        "Name[ca@valencia]": "Connector del P7zip",
        "Name[ca]": "Connector del P7zip",
        "Name[cs]": "Modul pro p7zip",
        "Name[da]": "P7zip-plugin",
        "Name[de]": "P7zip-Modul",
        "Name[el]": "Πρόσθετο P7zip",
        "Name[es]": "Complemento P7zip",
        "Name[eu]": "P7zip plugina",
        "Name[fi]": "P7zip-liitännäinen",
        "Name[fr]": "Module externe « P7zip »",
        "Name[gl]": "Complemento de p7zip",
        "Name[ia]": "Plugin de P7zip",
        "Name[it]": "Estensione P7zip",
        "Name[ko]": "P7zip 플러그인",
        "Name[nl]": "P7zip-plug-in",
        "Name[nn]": "P7zip-tillegg",
        "Name[pl]": "Wtyczka p7zip",
        "Name[pt]": "'Plugin' do P7zip",
        "Name[ru]": "Модуль P7zip",
        "Name[sk]": "Plugin P7zip",
        "Name[sl]": "Vstavek P7zip",
        "Name[sr@ijekavian]": "Прикључак за П7зип",
        "Name[sr@ijekavianlatin]": "Priključak za p7zip",
        "Name[sr@latin]": "Priključak za p7zip",
        "Name[sr]": "Прикључак за П7зип",
        "Name[sv]": "P7zip-insticksprogram",
        "Name[tr]": "P7zip eklentisi",
        "Name[uk]": "Додаток P7zip",
        "Name[x-test]": "xxP7zip pluginxx",
        "Name[zh_CN]": "P7zip 插件",
        "Name[zh_TW]": "P7zip 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadOnlyExecutables": [
        "7z"
    ],
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Kerfuffle-ReadWriteExecutables": [
        "7z"
    ],
    "X-KDE-Priority": 180,
    "application/x-7z-compressed": {
        "CompressionLevelDefault": 5,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0,
        "CompressionMethodDefault": "LZMA2",
        "CompressionMethods": {
            "BZip2": "BZip2",
            "Copy": "Copy",
            "Deflate": "Deflate",
            "LZMA": "LZMA",
            "LZMA2": "LZMA2",
            "PPMd": "PPMd"
        },
        "EncryptionMethodDefault": "AES256",
        "EncryptionMethods": [
            "AES256"
        ],
        "HeaderEncryption": true,
        "SupportsMultiVolume": true,
        "SupportsTesting": true
    },
    "application/zip": {
        "CompressionLevelDefault": 5,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0,
        "CompressionMethodDefault": "Deflate",
        "CompressionMethods": {
            "BZip2": "BZip2",
            "Copy": "Copy",
            "Deflate": "Deflate",
            "Deflate64": "Deflate64",
            "LZMA": "LZMA",
            "PPMd": "PPMd"
        },
        "Encryption": true,
        "EncryptionMethodDefault": "AES256",
        "EncryptionMethods": [
            "AES256",
            "AES192",
            "AES128",
            "ZipCrypto"
        ],
        "SupportsMultiVolume": true,
        "SupportsTesting": true
    }
}

==> ark-18.08.1.tar.xz: ark-18.08.1/plugins/cli7zplugin/kerfuffle_cli7z.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for the zip and 7z archive formats",
        "Description[ca@valencia]": "Implementació completa dels formats d'arxiu «zip» i «7z»",
        "Description[ca]": "Implementació completa dels formats d'arxiu «zip» i «7z»",
        "Description[cs]": "Plná podpora archivačních formátů zip a 7z",
        "Description[da]": "Fuld understøttelse af zip- og 7z-arkivformater",
        "Description[de]": "Vollständige Unterstützung für Zip- und 7z-Archivformate",
        "Description[el]": "Πλήρης υποστήριξη για την αρχειοθήκη μορφής zip και 7z",
        "Description[es]": "Uso total de los formatos de archivos comprimidos zip y 7z",
        "Description[eu]": "zip eta 7z artxibo fitxategientzako euskarri osoa",
        "Description[fi]": "Täysi Zip- ja 7z-tiedostomuotojen tuki",
        "Description[fr]": "Prise en charge complète des formats d'archive zip et 7z",
        "Description[gl]": "Compatibilidade total cos formatos de arquivo zip and 7z.",
        "Description[it]": "Supporto completo per i formati di archivi zip e 7z",
        "Description[ko]": "zip 및 7z 압축 형식 지원",
        "Description[nl]": "Volledige ondersteuning voor de zip- en 7z-archiefformaten",
        "Description[nn]": "Full støtte for arkivformata ZIP og 7z",
        "Description[pl]": "Pełna obsługa dla archiwów zip oraz 7z",
        "Description[pt]": "Suporte total para os formatos de pacotes ZIP e 7z",
        "Description[pt_BR]": "Suporte total para os formatos de arquivo ZIP e 7z",
        "Description[ru]": "Полная поддержка архивов ZIP и 7z",
        "Description[sk]": "Plná podpora pre archívne formáty zip a 7z",
        "Description[sl]": "Polna podpora za arhive vrste zip in 7z",
        "Description[sr@ijekavian]": "Пуна подршка за архивске формате ЗИП и 7зип",
        "Description[sr@ijekavianlatin]": "Puna podrška za arhivske formate ZIP i 7zip",
        "Description[sr@latin]": "Puna podrška za arhivske formate ZIP i 7zip",
        "Description[sr]": "Пуна подршка за архивске формате ЗИП и 7зип",
        "Description[sv]": "Fullt stöd för zip- och 7z-arkivformaten",
        "Description[tr]": "Zip ve 7z arşiv biçimleri için tam destek",
        "Description[uk]": "Повноцінна підтримка архівів у форматах zip і 7z",
        "Description[x-test]": "xxFull support for the zip and 7z archive formatsxx",
        "Description[zh_CN]": "完全支持 zip 和 7z 归档格式",
        "Description[zh_TW]": "對 zip 與 7z 壓縮檔格式的完整支援",
        "Id": "kerfuffle_cli7z",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "P7zip plugin",
        "Name[ca@valencia]": "Connector del P7zip",
        "Name[ca]": "Connector del P7zip",
        "Name[cs]": "Modul pro p7zip",
        "Name[da]": "P7zip-plugin",
        "Name[de]": "P7zip-Modul",
        "Name[el]": "Πρόσθετο P7zip",
        "Name[es]": "Complemento P7zip",
        "Name[eu]": "P7zip plugina",
        "Name[fi]": "P7zip-liitännäinen",
        "Name[fr]": "Module externe « P7zip »",
        "Name[gl]": "Complemento de p7zip",
        "Name[ia]": "Plugin de P7zip",
        "Name[it]": "Estensione P7zip",
        "Name[ko]": "P7zip 플러그인",
        "Name[nl]": "P7zip-plug-in",
        "Name[nn]": "P7zip-tillegg",
        "Name[pl]": "Wtyczka p7zip",
        "Name[pt]": "'Plugin' do P7zip",
        "Name[pt_BR]": "Plugin 7zip",
        "Name[ru]": "Модуль P7zip",
        "Name[sk]": "Plugin P7zip",
        "Name[sl]": "Vstavek P7zip",
        "Name[sr@ijekavian]": "Прикључак за П7зип",
        "Name[sr@ijekavianlatin]": "Priključak za p7zip",
        "Name[sr@latin]": "Priključak za p7zip",
        "Name[sr]": "Прикључак за П7зип",
        "Name[sv]": "P7zip-insticksprogram",
        "Name[tr]": "P7zip eklentisi",
        "Name[uk]": "Додаток P7zip",
        "Name[x-test]": "xxP7zip pluginxx",
        "Name[zh_CN]": "P7zip 插件",
        "Name[zh_TW]": "P7zip 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadOnlyExecutables": [
        "7z"
    ],
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Kerfuffle-ReadWriteExecutables": [
        "7z"
    ],
    "X-KDE-Priority": 180,
    "application/x-7z-compressed": {
        "CompressionLevelDefault": 5,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0,
        "CompressionMethodDefault": "LZMA2",
        "CompressionMethods": {
            "BZip2": "BZip2",
            "Copy": "Copy",
            "Deflate": "Deflate",
            "LZMA": "LZMA",
            "LZMA2": "LZMA2",
            "PPMd": "PPMd"
        },
        "EncryptionMethodDefault": "AES256",
        "EncryptionMethods": [
            "AES256"
        ],
        "HeaderEncryption": true,
        "SupportsMultiVolume": true,
        "SupportsTesting": true
    },
    "application/zip": {
        "CompressionLevelDefault": 5,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 0,
        "CompressionMethodDefault": "Deflate",
        "CompressionMethods": {
            "BZip2": "BZip2",
            "Copy": "Copy",
            "Deflate": "Deflate",
            "Deflate64": "Deflate64",
            "LZMA": "LZMA",
            "PPMd": "PPMd"
        },
        "Encryption": true,
        "EncryptionMethodDefault": "AES256",
        "EncryptionMethods": [
            "AES256",
            "AES192",
            "AES128",
            "ZipCrypto"
        ],
        "SupportsMultiVolume": true,
        "SupportsTesting": true
    }
}
